@@ -1,7 +1,6 @@
 from typing import List
 from alpacka.functions import statistic_methods as s
 from alpacka.functions import presentation_functions as pf
-from configparser import ConfigParser
 
 
 class ncof_pipeline:
@@ -23,11 +22,12 @@ class ncof_pipeline:
     #### Check input data type ####
     def check_data_type(self, data):
         """self function that checks if the input data type is known to be compatible with the remaining functions"""
-        if type(data).__name__ != 'list':
+        ok = ['list' , 'Series']
+        if type(data).__name__ not in ok:
             raise TypeError(
                 f"Input type ({type(data)}) not supported as an input. "
                 f"Please format the input in on of the supported formats. "
-                f"Supported formats: List")
+                f"Supported formats: {ok}")
 
     #### calc_NCOF ####
     def calc_ncof(self, data: List[List[str]], labels: List[int]):
@@ -194,10 +194,9 @@ class ncof_pipeline:
         """Returns the Class_perspective class variable"""
         return self.Class_perspective
 
-    def print_outliers_to_terminal(lst: List[List[list]], sort: bool = True):
+    def print_outliers_to_terminal(self, lst: List[List[list]], sort: bool = True):
         """
         prints the input text outliers to the terminal window with sorted into the sigma outlier
-        @param path: str
         @param lst: list
         @param sort: bool
         """
